
# Splaragon

[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://choosealicense.com/licenses/mit/)
[![contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/maina401/splaragon/issues)
[![HitCount](https://hits.dwyl.com/maina401/splaragon.svg?style=flat-square&show=unique)](http://hits.dwyl.com/maina401/splaragon)


This is an open source project that provides a starter kit for building web applications with Tailwind CSS, Laravel 10, and the Argon Pro Tailwind UI Kit.

## Introduction
The Argon Dashboard is a complex and innovative dashboard created by Creative Tim. It features bold elements and beautiful design, made up of hundreds of elements, designed blocks, and fully coded pages. The dashboard is built with over 300 frontend individual elements, like buttons, inputs, navbars, navtabs, cards, or alerts, giving you the freedom of choosing and combining. All components can take variations in color, that you can easily modify using SASS files and classes.

Splade provides a super easy way to build Single Page Applications (SPA) using standard Laravel Blade templates, enhanced with renderless Vue 3 components. With Splade, you can write your app using the simplicity of Blade and still have the full power of Vue.js. It provides features like:

Links and form submissions without full page reload
Modals and slideovers that can show any route (and support for nested modals)
Beautiful form components with Eloquent Model binding, validation, datetime picker, searchable and taggable selects, and async uploads
A DataTables-like table component that supports auto-fill, searching, filtering, sorting, toggling, and pagination
This Tailwind CSS Admin Starter Kit is based on the Argon Dashboard and Splade, and includes pre-built design blocks, making the development process seamless. You can easily switch from our pages to the real website, saving you a lot of time going from prototyping to full-functional code.

## Acknowledgements

- [The Laravel Framework](https://laravel.com) for the PHP framework
- [Creative Tim](https://www.creative-tim.com/product/argon-dashboard-pro-tailwind) for the Argon Dashboard
- [Laravel Splade](https://splade.dev/) for the SPA functionality


## Features

- Light/dark mode toggle
- Live previews
- Fullscreen mode
- Cross platform
- Splade for building Single Page Applications (SPA) with Laravel Blade templates and Vue.js
- Links and form submissions without full page reload
- Modals and slideovers that can show any route (and support for nested modals)
- Beautiful form components with Eloquent Model binding, validation, datetime picker, searchable and taggable selects, and async uploads
- A DataTables-like table component that supports auto-fill, searching, filtering, sorting, toggling, and pagination
- A dashboard with basic statistics
- Authentication, User registration, Password reset, Email verification, 2FA, and more
- User profile and settings pages
- CRUD examples for managing users and roles
- many more features check them out

## Run Locally

Clone the project

```bash
  composer create-project maina401/splaragon your-project-name dev-master
```

Go to the project directory

```bash
  cd your-project-name
```

Seed Users and Roles

```bash
  php artisan migrate && php artisan db:seed
```

And away you go ...

```bash
  php artisan serve
```
---
#### visit http://127.0.0.1:8000


## Authors

- [Mugwanjira Maina](https://www.github.com/maina401)


## Contributing

Contributions are always welcome!

To ensure that your contributions are accepted and to maintain a respectful and inclusive environment for all contributors, please follow these guidelines when contributing.

### Contributing Code
- Fork the repository and create a new branch from main.
- Write your code and test it locally.
- Push your branch to your fork and create a pull request.
-  Please ensure that your code follows the existing coding conventions and style guidelines in the repository.
- Your pull request will be reviewed by a maintainer, who may request changes or ask for clarification.
### Reporting Bugs or Requesting Features
- Check the issues page to ensure that the bug or feature request hasn't already been reported.
- If it hasn't, please create a new issue and provide as much detail as possible.
- Use a clear and concise title and provide a detailed description of the bug or feature request.
- Include any relevant screenshots or error messages.
- Be patient while the issue is reviewed and responded to by a maintainer.
### Thank You!
We appreciate your contributions to our project, and we'll do our best to respond to issues and pull requests as soon as possible. We recognize that your time is valuable and we want to make contributing as easy and rewarding as possible.

Please note that this is an open-source project, and contributions are voluntary. We may not be able to address every issue or feature request, but we will do our best to consider all contributions and respond in a timely manner.

Thank you for your support and for helping to make splaragon even better!

## License

This project is open source software licensed under the [MIT](https://choosealicense.com/licenses/mit/) License


## Screenshots

![App Screenshot](https://cdn.jsdelivr.net/gh/maina401/splaragon/public/Screenshot%202023-02-19%20124753.png)

